[cmake-developers] License of the dashboard:cmake_common.cmake script

2012-01-18 Thread Michael Wild
Hi all

I based my dashboard driver script on the one used by CMake
(http://cmake.org/gitweb?p=cmake.git;a=blob;f=cmake_common.cmake;hb=refs/heads/dashboard)
and wonder what it's license is. Is it the usual 3-clause BSD-style license?

Michael
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] License of the dashboard:cmake_common.cmake script

2012-01-18 Thread Brad King
On Wed, Jan 18, 2012 at 8:41 AM, Michael Wild them...@gmail.com wrote:
 I based my dashboard driver script on the one used by CMake
 (http://cmake.org/gitweb?p=cmake.git;a=blob;f=cmake_common.cmake;hb=refs/heads/dashboard)
 and wonder what it's license is. Is it the usual 3-clause BSD-style license?

Yes, the notice was simply missing.  I added it:

  http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fe760baa

Thanks!
-Brad
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] License of the dashboard:cmake_common.cmake script

2012-01-18 Thread Michael Wild
On 01/18/2012 03:16 PM, Brad King wrote:
 On Wed, Jan 18, 2012 at 8:41 AM, Michael Wild them...@gmail.com wrote:
 I based my dashboard driver script on the one used by CMake
 (http://cmake.org/gitweb?p=cmake.git;a=blob;f=cmake_common.cmake;hb=refs/heads/dashboard)
 and wonder what it's license is. Is it the usual 3-clause BSD-style license?
 
 Yes, the notice was simply missing.  I added it:
 
   http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fe760baa
 
 Thanks!
 -Brad

Great, thanks for the fast response!

Michael
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


[cmake-developers] [CMake 0012882]: MinGW makefile project cannot be build in parallel mode

2012-01-18 Thread Mantis Bug Tracker

The following issue has been SUBMITTED. 
== 
http://public.kitware.com/Bug/view.php?id=12882 
== 
Reported By:Galeazzi
Assigned To:
== 
Project:CMake
Issue ID:   12882
Category:   CMake
Reproducibility:always
Severity:   minor
Priority:   normal
Status: new
== 
Date Submitted: 2012-01-18 09:48 EST
Last Modified:  2012-01-18 09:48 EST
== 
Summary:MinGW makefile project cannot be build in parallel
mode
Description: 
I generated a MakeFile Project (MinGW) and I'd like to speed up the
build process using -j N option. So I launched:
make -j 2 all.
Unfortunately I noticed that the Makefile, generated by CMake self,
contains this row: $(MAKE) -f CMakeFiles\Makefile2 all , so Makefile2
won't be executed in parallel mode. 
On the other hand if I manually launch 
make -j 2 -f CMakeFiles\Makefile2 all, the project will be built in parallel
mode reducing the needed time from 25 min to 14 min.

Steps to Reproduce: 
1 - Generate a MinGW Makefile on a Windows machine
2 - Build the project launching make -j 2 all
== 

Issue History 
Date ModifiedUsername   FieldChange   
== 
2012-01-18 09:48 Galeazzi   New Issue
==

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


[cmake-developers] Support for imported targets in CMAKE_REQUIRED_LIBRARIES

2012-01-18 Thread Alexander Neundorf
Hi,

the variable CMAKE_REQUIRED_LIBRARIES is used by several of the check-modules 
for listing additional libraries which should be linked.
It is common to use variables set by Find-modules for this, e.g.
set(CMAKE_REQUIRED_LIBRARIES ${JPEG_LIBRARIES} )

Now, if the module did not simply set JPEG_LIBRARIES to the full path, but 
instead created an imported target, e.g. FindJPEG::libjpeg, this leads to a 
problem.
The check-modules will simply append this to the linker command, so there will 
be -lFindJPEG::libjpeg, which will not work.
This actually happened in KDE the first time more than 2 years ago.

On cmake stage there is now a branch HandleTargetsInCMakeRequiredLibraries, 
where I ported the solution from KDE to CMake and applied it to all places 
where CMAKE_REQUIRED_LIBRARIES is used.
I did not test it yet (but it should work, since it is exactly the same as in 
KDE).

Please have a look at it.

Alex
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [cmake-developers] Support for imported targets in CMAKE_REQUIRED_LIBRARIES

2012-01-18 Thread Rolf Eike Beer
Alexander Neundorf wrote:
 On Wednesday 18 January 2012, Alexander Neundorf wrote:
  Hi,
  
  the variable CMAKE_REQUIRED_LIBRARIES is used by several of the
  check-modules for listing additional libraries which should be linked.
  It is common to use variables set by Find-modules for this, e.g.
  set(CMAKE_REQUIRED_LIBRARIES ${JPEG_LIBRARIES} )
  
  Now, if the module did not simply set JPEG_LIBRARIES to the full path,
  but instead created an imported target, e.g. FindJPEG::libjpeg, this
  leads to a problem.
  The check-modules will simply append this to the linker command, so
  there
  will be -lFindJPEG::libjpeg, which will not work.
  This actually happened in KDE the first time more than 2 years ago.
  
  On cmake stage there is now a branch
  HandleTargetsInCMakeRequiredLibraries, where I ported the solution from
  KDE to CMake and applied it to all places where
  CMAKE_REQUIRED_LIBRARIES is used.
  I did not test it yet (but it should work, since it is exactly the same
  as in KDE).
  
  Please have a look at it.
 
 It's here:
 http://cmake.org/gitweb?p=stage/cmake.git;a=log;h=refs/heads/HandleTargetsIn
 CMakeRequiredLibraries

Some minor nitpicks just when I read through it:

-you introduced double newlines after the include() in many modules
-the doc header of the module says CMAKE_REQUIRED_LIBRARY instead of ...IES
-is it really KDE4__kdeui or KDE4_kdeui (1 vs. 2 underscores)?
-I'm no native speaker, but shouldn't it be 100 is arbitrarily chosen? (and 
an extra space after the ( removed
-is it useful to call list(REMOVE_DUPLICATES) at the end? If I link in 3 KDE 
libs I otherwise would get the whole dependencies of e.g. kdecore at least 3 
times, no?

Eike

signature.asc
Description: This is a digitally signed message part.
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers

[CMake] about generated Windows executable

2012-01-18 Thread nico

Hi,
first, i would like to thank you for this great tool...

i'm using cmake on macos 10.7.2, for my project cmake create osx bundle, 
windows executable, and very soon linux executable.

the windows executable is generated thanks to a cross mingw compiler.
the problem i'm facing is when i launch my program on windows, a dos 
shell like appears...

is there's a way to prevent that ?

also, but not very much important, can i use cpack in nsis way on the 
mac to create a windows installer.


best regards
nico
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] about generated Windows executable

2012-01-18 Thread Rolf Eike Beer
 Hi,
 first, i would like to thank you for this great tool...

 i'm using cmake on macos 10.7.2, for my project cmake create osx bundle,
 windows executable, and very soon linux executable.
 the windows executable is generated thanks to a cross mingw compiler.
 the problem i'm facing is when i launch my program on windows, a dos
 shell like appears...
 is there's a way to prevent that ?

add_executable(myapp WIN32 ...)

That WIN32 flag is ignored on all other platforms, so no need for an if()
here.

Eike
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] CMakeCache parse errors from line breaks

2012-01-18 Thread Zbyněk Novotný
Hello all,

I'm suffering from the issue described below.

I have created a script designed for use with CMake's find_package 
functionality, essentially following the steps outlined here:

http://www.vtk.org/Wiki/CMake:How_To_Find_Libraries#Writing_find_modules

In my case, I use execute_process to call an external application three times 
in order to obtain various compiler flag values it prints on stdout, storing 
the result of each call in separate variable. So far so good.

The issue arises when I use the find_package_handle_standard_args function. In 
the course of its processing, it calls the find_package_message that adds to 
CMakeCache.txt this internal variable:

FIND_PACKAGE_MESSAGE_DETAILS_Metaserver:INTERNAL=[-I/usr/include
][-L/usr/lib -L/usr/lib/metaserver][/usr/lib/metaserver/handlers
]

Subsequent processing of the cache file by CMake yields the parsing error I've 
been struggling with.

I'm pretty sure there are no superficial newlines in the output of the app I 
call other than those at the end of each string, but I believe that if those 
were the issue, the second value would have had a line break at its end -- just 
before the closing square bracket -- as well.

I've found two ways to get around this problem so far -- either I call my 
find_package script with the quiet argument, but then I won't know if the 
process succeeded, or I can manually edit the cache file and put all three 
values on the same line. That change, of course, won't live past the next cache 
file recreation.

So, if anyone knows a way that will fix this problem, I'll be most grateful to 
hear about it.

Thanks very much in advance for all tips and comments.

Cheers, Zbynek
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] Install an executable with his libraries

2012-01-18 Thread Anthony Todisco
Hello,

I'm new with CMake and for a project I try to build and install a program.
I've done some research on the forum and try what have found but nothing
seems to work :/.

Here is my configuration and my CMakeList

Application/
 |___ Bin
 |___ Includes
  |___ BaseLib
 |___ BaseObject.h
  |___ ComposeLib
 |___ ComposeObject.h
  |___ Manager
 |___ manager.h
 |___ Src
  |___ BaseLib
 |___ BaseObject.cpp
 |___ CMakeList.txt (2)
  |___ ComposeLib
 |___ ComposeObject.cpp
 |___ CMakeList.txt (3)
  |___ Manager
 |___ Manager.cpp
 |___ CMakeList.txt (4)
 |___ CMakeList.txt (1)

The CMakeList in the root is

# Set the cmake version
cmake_minimum_required(VERSION 2.6)
 
set(BUILD_SHARED_LIBS ON)
set(BUILD_PATH Bin/${CMAKE_BUILD_TYPE}/)
MESSAGE( General build path ${BUILD_PATH} )
 
# Set the list of directory which contain the other CMakeList
add_subdirectory(Src/BaseLib)
add_subdirectory(Src/ComposeLib)
add_subdirectory(Src/Manager)


*The CMakeList for BaseLib is*

# Set the cmake version
cmake_minimum_required(VERSION 2.6)
 
# Set the project name
project(BaseLib)
 
# Configure project
set(BUILD_SHARED_LIBS ON)
set(BUILD_PATH ${CMAKE_BUILD_TYPE}/)
 
#Display Build path
set(LIBRARY_OUTPUT_PATH ../../Bin/${BUILD_PATH})
 
#Include .h files directory
include_directories(../../Includes/BaseLib)
 
#Define librarie
add_library(
BaseLib 
SHARED
   ../../Includes/BaseLib/BaseObject.h
  BaseObject.cpp
)
 
set_target_properties(BaseLib PROPERTIES PREFIX )
install(TARGETS BaseLib 
  RUNTIME DESTINATION bin COMPONENT libraries
 LIBRARY DESTINATION lib COMPONENT libraries
 ARCHIVE DESTINATION lib/static COMPONENT libraries)

*The CMakeList for ComposeLib is*

# Set the cmake version
cmake_minimum_required(VERSION 2.6)
 
# Set the project name
project(ComposeLib )
 
# Configure project
set(BUILD_SHARED_LIBS ON)
set(BUILD_PATH ${CMAKE_BUILD_TYPE}/)
 
#Display Build path
set(LIBRARY_OUTPUT_PATH ../../Bin/${BUILD_PATH})
 
#Include .h files directory
include_directories(../../Includes/BaseLib ../../Includes/ComposeLib)
link_directories(../../Bin/${BUILD_PATH})
 
#Define librarie
add_library(
ComposeLib 
SHARED
   ../../Includes/ComposeLib/ComposeObject.h
  ComposeObject.cpp
)

target_link_libraries(
ComposeLib
BaseLib
)
 
set_target_properties(ComposeLib PROPERTIES PREFIX )
install(TARGETS ComposeLib
  RUNTIME DESTINATION bin COMPONENT libraries
 LIBRARY DESTINATION lib COMPONENT libraries
 ARCHIVE DESTINATION lib/static COMPONENT libraries)

And finally the *CMakeList for the Manager*


# Set the cmake version
cmake_minimum_required(VERSION 2.6)
 
# Set the project name
project(Manager)
 
# Configure project
set(BUILD_SHARED_LIBS ON)
set(BUILD_PATH ${CMAKE_BUILD_TYPE}/)
set(EXECUTABLE_OUTPUT_PATH ../../Bin/${BUILD_PATH})
 
#Include .h files directory
include_directories(../../Includes/BaseLib 
../../Includes/ComposeLib
../../Includes/Manager)
 
#Define link libraries folder
link_directories(../../Bin/${BUILD_PATH})
 
add_executable(
Manager
../../Includes/Manager/Manager.h
Manager.cpp
)
 
target_link_libraries(
Manager
BaseLib 
ComposeLib
pthread
)
 
set_target_properties(Manager PROPERTIES PREFIX )
install(TARGETS Manager
RUNTIME DESTINATION bin COMPONENT libraries
 LIBRARY DESTINATION lib COMPONENT libraries
 ARCHIVE DESTINATION lib/static COMPONENT libraries)

The build works fine and if I launch manager on the bin directory from the
build tree, there is no problem. However, when I use make install, all the
files are correctly installed /usr/local/lib and /usr/local/bin but I can't
launch Manager exectuable. A message informs me that the executable can't
find BaseLib.so.

I don't know where my error is :/.
Thank you for all the help you can provide me.

ps: sorry for my english, I'm French.

--
View this message in context: 
http://cmake.3232098.n2.nabble.com/Install-an-executable-with-his-libraries-tp7199530p7199530.html
Sent from the CMake mailing list archive at Nabble.com.
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] about generated Windows executable

2012-01-18 Thread nico



Le 18/01/12 09:35, Rolf Eike Beer a écrit :

Hi,
first, i would like to thank you for this great tool...

i'm using cmake on macos 10.7.2, for my project cmake create osx bundle,
windows executable, and very soon linux executable.
the windows executable is generated thanks to a cross mingw compiler.
the problem i'm facing is when i launch my program on windows, a dos
shell like appears...
is there's a way to prevent that ?

add_executable(myapp WIN32 ...)

That WIN32 flag is ignored on all other platforms, so no need for an if()
here.

that did the trick, thank you for your help.
best regards


Eike
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] CMakeCache parse errors from line breaks

2012-01-18 Thread Rolf Eike Beer
 Hello all,

 I'm suffering from the issue described below.

 I have created a script designed for use with CMake's find_package
 functionality, essentially following the steps outlined here:

 http://www.vtk.org/Wiki/CMake:How_To_Find_Libraries#Writing_find_modules

 In my case, I use execute_process to call an external application three
 times in order to obtain various compiler flag values it prints on stdout,
 storing the result of each call in separate variable. So far so good.

 The issue arises when I use the find_package_handle_standard_args
 function. In the course of its processing, it calls the
 find_package_message that adds to CMakeCache.txt this internal variable:

 FIND_PACKAGE_MESSAGE_DETAILS_Metaserver:INTERNAL=[-I/usr/include
 ][-L/usr/lib -L/usr/lib/metaserver][/usr/lib/metaserver/handlers
 ]

 Subsequent processing of the cache file by CMake yields the parsing error
 I've been struggling with.

 I'm pretty sure there are no superficial newlines in the output of the app
 I call other than those at the end of each string, but I believe that if
 those were the issue, the second value would have had a line break at its
 end -- just before the closing square bracket -- as well.

execute_process(... OUTPUT_STRIP_TRAILING_WHITESPACE)

HTHHAND,

Eike
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] Install an executable with his libraries

2012-01-18 Thread Rolf Eike Beer
 Hello,

 I'm new with CMake and for a project I try to build and install a program.
 I've done some research on the forum and try what have found but nothing
 seems to work :/.

[...]

 The build works fine and if I launch manager on the bin directory from the
 build tree, there is no problem. However, when I use make install, all the
 files are correctly installed /usr/local/lib and /usr/local/bin but I
 can't
 launch Manager exectuable. A message informs me that the executable can't
 find BaseLib.so.

 I don't know where my error is :/.

export LD_LIBRARY_PATH=/usr/local/lib:${LD_LIBRARY_PATH}

Eike
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] Install an executable with his libraries

2012-01-18 Thread Anthony Todisco
Thank you very much, it works fine now :D.

I've missed this step :/

2012/1/18 Rolf Eike Beer e...@sf-mail.de

  Hello,
 
  I'm new with CMake and for a project I try to build and install a
 program.
  I've done some research on the forum and try what have found but nothing
  seems to work :/.

 [...]

  The build works fine and if I launch manager on the bin directory from
 the
  build tree, there is no problem. However, when I use make install, all
 the
  files are correctly installed /usr/local/lib and /usr/local/bin but I
  can't
  launch Manager exectuable. A message informs me that the executable can't
  find BaseLib.so.
 
  I don't know where my error is :/.

 export LD_LIBRARY_PATH=/usr/local/lib:${LD_LIBRARY_PATH}

 Eike
 --

 Powered by www.kitware.com

 Visit other Kitware open-source projects at
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at:
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake

Re: [CMake] CMakeCache parse errors from line breaks

2012-01-18 Thread Zbyněk Novotný
Hello Rolf,

that indeed did the trick. How could I have missed that parameter?

Thanks so very much for your helpful _and fast_ reply. Much appreciated.

Cheers, Zbynek.

  Původní zpráva 
 Od: Rolf Eike Beer e...@sf-mail.de
 Předmět: Re: [CMake] CMakeCache parse errors from line breaks
 Datum: 18.1.2012 11:01:15
 
  Hello all,
 
  I'm suffering from the issue described below.
 
  I have created a script designed for use with CMake's find_package
  functionality, essentially following the steps outlined here:
 
  http://www.vtk.org/Wiki/CMake:How_To_Find_Libraries#Writing_find_modules
 
  In my case, I use execute_process to call an external application three
  times in order to obtain various compiler flag values it prints on stdout,
  storing the result of each call in separate variable. So far so good.
 
  The issue arises when I use the find_package_handle_standard_args
  function. In the course of its processing, it calls the
  find_package_message that adds to CMakeCache.txt this internal variable:
 
  FIND_PACKAGE_MESSAGE_DETAILS_Metaserver:INTERNAL=[-I/usr/include
  ][-L/usr/lib -L/usr/lib/metaserver][/usr/lib/metaserver/handlers
  ]
 
  Subsequent processing of the cache file by CMake yields the parsing error
  I've been struggling with.
 
  I'm pretty sure there are no superficial newlines in the output of the app
  I call other than those at the end of each string, but I believe that if
  those were the issue, the second value would have had a line break at its
  end -- just before the closing square bracket -- as well.
 
 execute_process(... OUTPUT_STRIP_TRAILING_WHITESPACE)
 
 HTHHAND,
 
 Eike
 --
 
 Powered by www.kitware.com
 
 Visit other Kitware open-source projects at
 http://www.kitware.com/opensource/opensource.html
 
 Please keep messages on-topic and check the CMake FAQ at:
 http://www.cmake.org/Wiki/CMake_FAQ
 
 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake
 
 
 
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] Install an executable with his libraries

2012-01-18 Thread Eric Noulard
2012/1/18 Anthony Todisco todisco.anthony...@gmail.com:
 Thank you very much, it works fine now :D.

 I've missed this step :/

On Unix you can configure RPATH in order to avoid the LD_LIBRARY_PATH update
and/or tolerate more easily multiple version of the same lib for
different executable.

Have a look at:
http://www.cmake.org/Wiki/CMake_RPATH_handling


-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] debug git fetch

2012-01-18 Thread Tom Deblauwe

Hello,

In Ctest: How can I get the loggings of the git fetch command? I keep 
getting that /usr/bin/git fetch has failed when doing an update. So 
I see in the ctest source code that there is some extra logging for git, 
but using -VV --debug as extra params for the ctest call is not 
producing the git loggings. How can I get them?


Thanks,
Best regards,
Tom,
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] QT_IMPORTS_DIR when dit does not exist yet

2012-01-18 Thread Jonathan Riddell
Some Ubuntu developers are having an issue where QT_IMPORTS_DIR is not defined 
when that directory does not yet exist.

https://bugs.launchpad.net/ubuntu/+source/cmake/+bug/894805

I have worked around it with http://paste.kde.org/188366/ but I
suspect I'm not understanding what that code does and it's not a
proper fix.  Any thoughts on a better way?

Jonathan
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] cpack -G NSIS

2012-01-18 Thread Andrea Crotti

Thanks for the feedback,
however I tried again with another cmake file, which should actually do 
something.

What I would like to do is to:
- get the project name and a list of packages (just directories) to install
- install them somewhere (now the destination is not set correctly).

Should this work in general?

cmake_minimum_required(VERSION 2.6)
#TODO: should take from the python environment

# setting variables from some known build generated files
# probably we can also pass options directly to CMake
file(STRINGS project_name.txt project_name)
file(STRINGS package_list.txt packages)

project(${project_name})

# include can be used to add more configurations??

# # install all the given automatically
install(
  DIRECTORY ${packages}
  DESTINATION test_ddest
  )

#TODO: how do I get the correct destination for windows?

# now the packages variable should contain something

# this include all the necessary
include(CPack)

But I still get the same error using NSIS (works with TGZ):

CPack: /build/src/cmake-2.8.7/Source/CPack/cpack.cxx:211 Enable Debug
/build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1162 Looking 
for CMAKE_ROOT: /usr/share/cmake-2.8
/build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:941 
cmCPackNSISGenerator::SetOption(CMAKE_ROOT, /usr/share/cmake-2.8)
/build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:941 
cmCPackNSISGenerator::SetOption(CPACK_GENERATOR, NSIS)
/build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1145 Warning, 
GetOption return NULL for: CPACK_PROJECT_CONFIG_FILE
/build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1145 Warning, 
GetOption return NULL for: CPACK_INCLUDE_TOPLEVEL_DIRECTORY
/build/src/cmake-2.8.7/Source/CPack/cmCPackNSISGenerator.cxx:355 
cmCPackNSISGenerator::Initialize()
/build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1145 Warning, 
GetOption return NULL for: CPACK_TOPLEVEL_DIRECTORY

terminate called after throwing an instance of 'std::logic_error'
  what():  basic_string::_S_construct null not valid
aborted
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] show cpack variables

2012-01-18 Thread Andrea Crotti
cmake --help-variable-list shows me all the global variables defined, 
but how do I
see for example all the possible variables that are defined only when I 
include cpack?


And how do I get the documentation for a function like 
cpack_add_component for example?


Thanks,
Andrea
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] QT_IMPORTS_DIR when dit does not exist yet

2012-01-18 Thread Andreas Pakulat
On 18.01.12 16:06:28, Jonathan Riddell wrote:
 Some Ubuntu developers are having an issue where QT_IMPORTS_DIR is not 
 defined when that directory does not yet exist.
 
 https://bugs.launchpad.net/ubuntu/+source/cmake/+bug/894805
 
 I have worked around it with http://paste.kde.org/188366/ but I
 suspect I'm not understanding what that code does and it's not a
 proper fix.  Any thoughts on a better way?

Do you expect the imports directory to exist before being able to
install something there? If not then this is not fixable since its not
possible anymore to decide wether the cross-compile stuff applies or the
qmake-variable should be taken (see the foreach right below your patched
line). If imports is supposed to at least exist, then one could simply
iterate manually over all possible locations and take the first one for
which file(EXISTS) returns true.

That being said, one could argue that a Qt installation without at least
Qt/widgets is broken wrt. QML, so maybe the packages containing the
standard Qt qml files should actually be a required dependency for the
declarative module.

Andreas

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] External projects and targets

2012-01-18 Thread Francisco Requena Espí
Hi,

I'm currently porting a project into CMake under OSX.

Here's how it should work:

PROJECT
- DEPENDENCY 1 (1 target)
-- DEPENDENCY 2 (3 targets)
-- DEPENDENCY 3 (2 targets)
-- DEPENDENCY 4 (8 targets)
- DEPENDENCY 5 (1 target)
...

So, dependency 1 depends on dependencies 2, 3 and 4. Project depends
on dependency 1 and 5. They are all CMake standalone projects.

I'm using ExternalProject_Add to build everything. But, if I do:

ExternalProject_Add(DEP_2 ...)

I lose every target (that means, I get a DEP_2 target instead of
DEP_2_TARGET_1, DEP_2_TARGET_3, DEP_2_TARGET_3), so I also lose every
defined build setting, specific of each target. That leads to
compiling errors (specific target flags are not set I think).

I've tried this on Xcode, I don't know about Visual Studio or other tools.

NOTE: Every individual project (leaf dependencies) builds standalone
without problem.

How should I do that?

Thanks!
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] show cpack variables

2012-01-18 Thread Eric Noulard
2012/1/18 Andrea Crotti andrea.crott...@gmail.com:
 cmake --help-variable-list shows me all the global variables defined, but
 how do I
 see for example all the possible variables that are defined only when I
 include cpack?

 And how do I get the documentation for a function like cpack_add_component
 for example?

This is a work-in-progress:
http://public.kitware.com/Bug/view.php?id=10067

which not progressing too fast currently because I lack time.
I'll try to push some branch with the beginning of the work this Week-End
this should makes it easier for other to join the effort.

-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] show cpack variables

2012-01-18 Thread Eric Noulard
2012/1/18 Eric Noulard eric.noul...@gmail.com:
 2012/1/18 Andrea Crotti andrea.crott...@gmail.com:
 cmake --help-variable-list shows me all the global variables defined, but
 how do I
 see for example all the possible variables that are defined only when I
 include cpack?

 And how do I get the documentation for a function like cpack_add_component
 for example?

 This is a work-in-progress:
 http://public.kitware.com/Bug/view.php?id=10067

 which not progressing too fast currently because I lack time.
 I'll try to push some branch with the beginning of the work this Week-End
 this should makes it easier for other to join the effort.

In the meantime you could try

cmake --help-module CPack
cmake --help-module CPackComponent
cmake --help-module CPackRPM

or open the corresponding CPackName.cmake files and read the initial
comment block.

-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] cpack -G NSIS

2012-01-18 Thread Eric Noulard
2012/1/18 Andrea Crotti andrea.crott...@gmail.com:
 Thanks for the feedback,
 however I tried again with another cmake file, which should actually do
 something.

May be you could zip up the sample project sources, this would be easier
and safer for me if I want to be able to reproduce your issue.


 What I would like to do is to:
 - get the project name and a list of packages (just directories) to install
 - install them somewhere (now the destination is not set correctly).

 Should this work in general?

 cmake_minimum_required(VERSION 2.6)
 #TODO: should take from the python environment

 # setting variables from some known build generated files
 # probably we can also pass options directly to CMake
 file(STRINGS project_name.txt project_name)
 file(STRINGS package_list.txt packages)

 project(${project_name})

 # include can be used to add more configurations??

 # # install all the given automatically
 install(
  DIRECTORY ${packages}
  DESTINATION test_ddest
  )

 #TODO: how do I get the correct destination for windows?

 # now the packages variable should contain something

 # this include all the necessary
 include(CPack)

 But I still get the same error using NSIS (works with TGZ):

 CPack: /build/src/cmake-2.8.7/Source/CPack/cpack.cxx:211 Enable Debug
 /build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1162 Looking for
 CMAKE_ROOT: /usr/share/cmake-2.8
 /build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:941
 cmCPackNSISGenerator::SetOption(CMAKE_ROOT, /usr/share/cmake-2.8)
 /build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:941
 cmCPackNSISGenerator::SetOption(CPACK_GENERATOR, NSIS)
 /build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1145 Warning,
 GetOption return NULL for: CPACK_PROJECT_CONFIG_FILE
 /build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1145 Warning,
 GetOption return NULL for: CPACK_INCLUDE_TOPLEVEL_DIRECTORY
 /build/src/cmake-2.8.7/Source/CPack/cmCPackNSISGenerator.cxx:355
 cmCPackNSISGenerator::Initialize()
 /build/src/cmake-2.8.7/Source/CPack/cmCPackGenerator.cxx:1145 Warning,
 GetOption return NULL for: CPACK_TOPLEVEL_DIRECTORY

 terminate called after throwing an instance of 'std::logic_error'
  what():  basic_string::_S_construct null not valid
 aborted



-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] CPack Directory entries in zip files

2012-01-18 Thread Jakub Zakrzewski
Hi.
That's not that issue but may be related.
What I mean is the internal structure of zip file. I need to have
these directories explicite listed in the internal file list of zip
file. Now they are only implicity created. For example for file name
'my/file.txt' I should have an entry for 'my' and 'my/file.txt' but
now I only have 'my/file.txt'.

Anyway, tomorrow I will start looking into CPack code to get it
solved. It also may be related to libarchive. But I think this is a
topic for dev mailing list.

2012/1/17 Eric Noulard eric.noul...@gmail.com:
 2012/1/17 Jakub Zakrzewski slither...@gmail.com:
 Hi All!

 Recently we've moved all our packaging to CMake. For historical
 reasons however, we need to have directory entries in our zip files.
 CPack unfortunately generates archives with only file entries
 included. Is possible to get desired behaviour by setting some
 variables or changing some config files (or however)?

 Nope (unless you put some dummy file inside those dirs).
 There is an open bug report on subject:
 http://public.kitware.com/Bug/view.php?id=8767

 Add yourself to the monitor list and you'll get follow-up.
 You can even give a hand for patching or testing if you want.

 --
 Erk
 Membre de l'April - « promouvoir et défendre le logiciel libre » -
 http://www.april.org



-- 
Pozdrowienia
Jakub Zakrzewski
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] building libs and specifying addition folders

2012-01-18 Thread Dev Guy
Hi,

I am relatively new to CMake and I've read the tutorial. However I
have a few questions.

1. How can I declare a CMakeLists file to create a project to build a
DLL or static lib ? I assume if I build a DLL on windows, it will
build as a shared lib on Linux

2. If my main source folder has 2 sub-folders, one that only includes
header files call is Include and another folder that contains source
files call it Utils. How do I add declare them to my CMakeLists files
so that both the header and addition source files are found and and
compiled in the main source folder to build the final binary.

Thanks,

-- 
Kind Regards,
Rajinder Yadav
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] Fwd: building libs and specifying addition folders

2012-01-18 Thread John Drescher
-- Forwarded message --
From: John Drescher dresche...@gmail.com
Date: Thu, Jan 19, 2012 at 1:00 AM
Subject: Re: [CMake] building libs and specifying addition folders
To: Dev Guy devguy...@gmail.com


On Wed, Jan 18, 2012 at 10:57 PM, Dev Guy devguy...@gmail.com wrote:
 Hi,

 I am relatively new to CMake and I've read the tutorial. However I
 have a few questions.

 1. How can I declare a CMakeLists file to create a project to build a
 DLL or static lib ? I assume if I build a DLL on windows, it will
 build as a shared lib on Linux

put SHARED in the add_library statement

For more info than that type the following from a command prompt or shell:

cmake --help-command add_library


 2. If my main source folder has 2 sub-folders, one that only includes
 header files call is Include and another folder that contains source
 files call it Utils. How do I add declare them to my CMakeLists files
 so that both the header and addition source files are found and and
 compiled in the main source folder to build the final binary.


add_subdirectory

Again for help:
cmake --help-command add_subdirectory


John


-- 
John M. Drescher
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] Fwd: building libs and specifying addition folders

2012-01-18 Thread Dev Guy
On Thu, Jan 19, 2012 at 1:01 AM, John Drescher dresche...@gmail.com wrote:
 -- Forwarded message --
 From: John Drescher dresche...@gmail.com
 Date: Thu, Jan 19, 2012 at 1:00 AM
 Subject: Re: [CMake] building libs and specifying addition folders
 To: Dev Guy devguy...@gmail.com


 On Wed, Jan 18, 2012 at 10:57 PM, Dev Guy devguy...@gmail.com wrote:
 Hi,

 I am relatively new to CMake and I've read the tutorial. However I
 have a few questions.

 1. How can I declare a CMakeLists file to create a project to build a
 DLL or static lib ? I assume if I build a DLL on windows, it will
 build as a shared lib on Linux

 put SHARED in the add_library statement

 For more info than that type the following from a command prompt or shell:

 cmake --help-command add_library


 2. If my main source folder has 2 sub-folders, one that only includes
 header files call is Include and another folder that contains source
 files call it Utils. How do I add declare them to my CMakeLists files
 so that both the header and addition source files are found and and
 compiled in the main source folder to build the final binary.


 add_subdirectory

 Again for help:
 cmake --help-command add_subdirectory


 John


 --
 John M. Drescher
 --

John thanks,

I was able to get a DLL built, now I have a program that want to link
against the lib and use the DLL.

What I've done is create a Lib folder under the source folder wanting
to use the lib, I copied over the lib find and header file. I added
the following to CMakeLists.txt

add_subdirectory(Lib)


target_link_libraries (SimpleTester UnitTest)

However I am seeing 2 errors:

Error 1, when I run CMake I see:

CMake Warning (dev) at CMakeLists.txt:6 (add_subdirectory):
  The source directory

C:/dev/Project/UnitTestSample/Lib

  does not contain a CMakeLists.txt file.

  CMake does not support this case but it used to work accidentally and is
  being allowed for compatibility.

  Policy CMP0014 is not set: Input directories must have CMakeLists.txt.  Run
  cmake --help-policy CMP0014 for policy details.  Use the cmake_policy
  command to set the policy and suppress this warning.
This warning is for project developers.  Use -Wno-dev to suppress it.

-- Configuring done
-- Generating done
-- Build files have been written to: C:/dev/Project/UnitTestSample/build

==

Error 2

When I build I get a link error, which I fix by copying over the lib
file into the build folder. How can I tell the linker from CMake where
to find the lib?

LINK : fatal error LNK1104: cannot open file 'UnitTest.lib'
LINK Pass 1 failed. with 2
NMAKE : fatal error U1077: 'C:\Program Files\CMake
2.8\bin\cmake.exe' : return code '0x'
Stop.
NMAKE : fatal error U1077: 'C:\Program Files\Microsoft Visual Studio
10.0\VC\BIN\nmake.exe' : retu
rn code '0x2'
Stop.
NMAKE : fatal error U1077: 'C:\Program Files\Microsoft Visual Studio
10.0\VC\BIN\nmake.exe' : retu
rn code '0x2'
Stop.
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[Cmake-commits] CMake branch, dashboard, updated. 849820219e84e251ad99121f738456f3743ba4fa

2012-01-18 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, dashboard has been updated
   via  849820219e84e251ad99121f738456f3743ba4fa (commit)
   via  fe760baa0af5287d8a27552fced1a646a042f1ed (commit)
  from  8daf9edd8a0a6390ef0eea0bbf0a7b12bf26ce7c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=849820219e84e251ad99121f738456f3743ba4fa
commit 849820219e84e251ad99121f738456f3743ba4fa
Author: Brad King brad.k...@kitware.com
AuthorDate: Wed Jan 18 09:12:00 2012 -0500
Commit: Brad King brad.k...@kitware.com
CommitDate: Wed Jan 18 09:12:00 2012 -0500

cmake_common: Remove source tree when .git is corrupted

Some dashboard builds run on scratch disks that arbitrarily remove files
that have not been accessed in a while.  Since Git uses O_NOATIME for
repository objects the .git repository files may disappear thus
corrupting the repository.  When this happens even git reset --hard
will fail, so wipe out the source tree to get a fresh clone.

diff --git a/cmake_common.cmake b/cmake_common.cmake
index f3a4cb3..2d7091a 100644
--- a/cmake_common.cmake
+++ b/cmake_common.cmake
@@ -193,6 +193,17 @@ if(EXISTS ${CTEST_SOURCE_DIRECTORY})
   if(CTEST_GIT_COMMAND)
 if(NOT EXISTS ${CTEST_SOURCE_DIRECTORY}/.git)
   set(vcs_refresh because it is not managed by git.)
+else()
+  execute_process(
+COMMAND ${CTEST_GIT_COMMAND} reset --hard
+WORKING_DIRECTORY ${CTEST_SOURCE_DIRECTORY}
+OUTPUT_VARIABLE output
+ERROR_VARIABLE output
+RESULT_VARIABLE failed
+)
+  if(failed)
+set(vcs_refresh because its .git may be corrupted.)
+  endif()
 endif()
   endif()
   if(vcs_refresh AND ${CTEST_SOURCE_DIRECTORY} MATCHES /CMake[^/]*)

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=fe760baa0af5287d8a27552fced1a646a042f1ed
commit fe760baa0af5287d8a27552fced1a646a042f1ed
Author: Brad King brad.k...@kitware.com
AuthorDate: Wed Jan 18 09:08:43 2012 -0500
Commit: Brad King brad.k...@kitware.com
CommitDate: Wed Jan 18 09:08:43 2012 -0500

cmake_common: Add copyright and license notice

Use the same OSI-approved 3-clause BSD license that covers CMake.

diff --git a/cmake_common.cmake b/cmake_common.cmake
index d1ca208..f3a4cb3 100644
--- a/cmake_common.cmake
+++ b/cmake_common.cmake
@@ -55,6 +55,38 @@
 #   set(ENV{FC}  /path/to/fc)   # Fortran compiler (optional)
 #   set(ENV{LD_LIBRARY_PATH} /path/to/vendor/lib) # (if necessary)
 
+#=
+# Copyright 2010-2012 Kitware, Inc.
+# All rights reserved.
+#
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions
+# are met:
+#
+# * Redistributions of source code must retain the above copyright
+#   notice, this list of conditions and the following disclaimer.
+#
+# * Redistributions in binary form must reproduce the above copyright
+#   notice, this list of conditions and the following disclaimer in the
+#   documentation and/or other materials provided with the distribution.
+#
+# * Neither the name of Kitware, Inc. nor the names of its contributors
+#   may be used to endorse or promote products derived from this
+#   software without specific prior written permission.
+#
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+# AS IS AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+#=
+
 cmake_minimum_required(VERSION 2.6.3 FATAL_ERROR)
 
 set(CTEST_PROJECT_NAME CMake)

---

Summary of changes:
 cmake_common.cmake |   43 +++
 1 files changed, 43 insertions(+), 0 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org

[Cmake-commits] CMake branch, next, updated. v2.8.7-2146-ga05fab1

2012-01-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  a05fab177193b56504df92f438dc22dba85e0c9e (commit)
   via  0541a03a4c913164868bcec09c21c455e14a7c70 (commit)
  from  95dd0f279c9a239b18c8c1f5f30eb94e131cc184 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a05fab177193b56504df92f438dc22dba85e0c9e
commit a05fab177193b56504df92f438dc22dba85e0c9e
Merge: 95dd0f2 0541a03
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 12:14:24 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Jan 18 12:14:24 2012 -0500

Merge topic 'eof-newlines' into next

0541a03 GenerateExportHeader test: add newlines before end of file


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=0541a03a4c913164868bcec09c21c455e14a7c70
commit 0541a03a4c913164868bcec09c21c455e14a7c70
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 00:01:08 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Jan 18 00:01:08 2012 +0100

GenerateExportHeader test: add newlines before end of file

diff --git a/Tests/CMakeCommands/target_link_libraries/depC.cpp 
b/Tests/CMakeCommands/target_link_libraries/depC.cpp
index 93410a8..60bed59 100644
--- a/Tests/CMakeCommands/target_link_libraries/depC.cpp
+++ b/Tests/CMakeCommands/target_link_libraries/depC.cpp
@@ -10,4 +10,4 @@ DepA DepC::getA()
 {
   DepA a;
   return a;
-}
\ No newline at end of file
+}
diff --git a/Tests/Module/GenerateExportHeader/nodeprecated/src/main.cpp 
b/Tests/Module/GenerateExportHeader/nodeprecated/src/main.cpp
index 445a652..eec46d3 100644
--- a/Tests/Module/GenerateExportHeader/nodeprecated/src/main.cpp
+++ b/Tests/Module/GenerateExportHeader/nodeprecated/src/main.cpp
@@ -6,4 +6,4 @@ int main(int, char**)
   SomeClass sc;
   sc.someMethod();
   return 0;
-}
\ No newline at end of file
+}
diff --git a/Tests/Module/GenerateExportHeader/override_symbol/main.cpp 
b/Tests/Module/GenerateExportHeader/override_symbol/main.cpp
index 445a652..eec46d3 100644
--- a/Tests/Module/GenerateExportHeader/override_symbol/main.cpp
+++ b/Tests/Module/GenerateExportHeader/override_symbol/main.cpp
@@ -6,4 +6,4 @@ int main(int, char**)
   SomeClass sc;
   sc.someMethod();
   return 0;
-}
\ No newline at end of file
+}
diff --git a/Tests/Module/GenerateExportHeader/override_symbol/someclass.cpp 
b/Tests/Module/GenerateExportHeader/override_symbol/someclass.cpp
index 7326b78..427ec29 100644
--- a/Tests/Module/GenerateExportHeader/override_symbol/someclass.cpp
+++ b/Tests/Module/GenerateExportHeader/override_symbol/someclass.cpp
@@ -4,4 +4,4 @@
 void SomeClass::someMethod() const
 {
 
-}
\ No newline at end of file
+}
diff --git a/Tests/Module/GenerateExportHeader/prefix/main.cpp 
b/Tests/Module/GenerateExportHeader/prefix/main.cpp
index d04ae3c..507f6fd 100644
--- a/Tests/Module/GenerateExportHeader/prefix/main.cpp
+++ b/Tests/Module/GenerateExportHeader/prefix/main.cpp
@@ -5,4 +5,4 @@ int main(int argc, char **argv)
 {
   UsePrefixClass upc;
   return upc.someMethod();
-}
\ No newline at end of file
+}
diff --git a/Tests/Module/GenerateExportHeader/prefix/useprefixclass.cpp 
b/Tests/Module/GenerateExportHeader/prefix/useprefixclass.cpp
index 8337ab8..1fd2cb2 100644
--- a/Tests/Module/GenerateExportHeader/prefix/useprefixclass.cpp
+++ b/Tests/Module/GenerateExportHeader/prefix/useprefixclass.cpp
@@ -4,4 +4,4 @@
 int UsePrefixClass::someMethod() const
 {
   return 0;
-}
\ No newline at end of file
+}

---

Summary of changes:
 Tests/CMakeCommands/target_link_libraries/depC.cpp |2 +-
 .../GenerateExportHeader/nodeprecated/src/main.cpp |2 +-
 .../GenerateExportHeader/override_symbol/main.cpp  |2 +-
 .../override_symbol/someclass.cpp  |2 +-
 Tests/Module/GenerateExportHeader/prefix/main.cpp  |2 +-
 .../GenerateExportHeader/prefix/useprefixclass.cpp |2 +-
 6 files changed, 6 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2148-g2980cf8

2012-01-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  2980cf8b255028a250c67d42351784af3cbf318d (commit)
   via  8d830436a42ec06555334b5c5ec73b41328d5f06 (commit)
  from  a05fab177193b56504df92f438dc22dba85e0c9e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=2980cf8b255028a250c67d42351784af3cbf318d
commit 2980cf8b255028a250c67d42351784af3cbf318d
Merge: a05fab1 8d83043
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 12:23:40 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Jan 18 12:23:40 2012 -0500

Merge topic 'test_find_modules' into next

8d83043 AllFindModules test: also check Qt3 modules if Qt4 is not found


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8d830436a42ec06555334b5c5ec73b41328d5f06
commit 8d830436a42ec06555334b5c5ec73b41328d5f06
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 18:23:21 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Jan 18 18:23:21 2012 +0100

AllFindModules test: also check Qt3 modules if Qt4 is not found

diff --git a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt 
b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
index 06b4736..8a38f06 100644
--- a/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
+++ b/Tests/CMakeOnly/AllFindModules/CMakeLists.txt
@@ -10,6 +10,11 @@ message(STATUS CTEST_FULL_OUTPUT)
 
 file(GLOB FIND_MODULES 
${CMAKE_CURRENT_SOURCE_DIR}/../../../Modules/Find*.cmake )
 
+macro(do_find MODULE_NAME)
+message(STATUSChecking Find${MODULE_NAME})
+find_package(${MODULE_NAME})
+endmacro(do_find)
+
 foreach(FIND_MODULE ${FIND_MODULES})
 string(REGEX REPLACE .*/Find(.*)\\.cmake$ \\1 MODULE_NAME 
${FIND_MODULE})
 
@@ -21,8 +26,14 @@ foreach(FIND_MODULE ${FIND_MODULES})
 if (NOT MODULE_NAME STREQUAL Qt AND
 NOT MODULE_NAME STREQUAL Qt3 AND
 NOT MODULE_NAME STREQUAL KDE3)
-message(STATUSChecking Find${MODULE_NAME})
-find_package(${MODULE_NAME})
+do_find(${MODULE_NAME})
 endif ()
 
 endforeach(FIND_MODULE)
+
+# Qt4 is not present, so we can check Qt3
+if(NOT QT4_FOUND)
+foreach(FIND_MODULE Qt3 Qt KDE3)
+do_find(${FIND_MODULE})
+endforeach(FIND_MODULE)
+endif(NOT QT4_FOUND)

---

Summary of changes:
 Tests/CMakeOnly/AllFindModules/CMakeLists.txt |   15 +--
 1 files changed, 13 insertions(+), 2 deletions(-)


hooks/post-receive
diff --git a/Modules/FindPerlLibs.cmake b/Modules/FindPerlLibs.cmake
index eea55f1..1c3525d 100644
--- a/Modules/FindPerlLibs.cmake
+++ b/Modules/FindPerlLibs.cmake
@@ -55,19 +55,6 @@ if (PERL_EXECUTABLE)
 string(REGEX REPLACE prefix='([^']+)'.* \\1 PERL_PREFIX 
${PERL_PREFIX_OUTPUT_VARIABLE})
   endif (NOT PERL_PREFIX_RESULT_VARIABLE)
 
-  ### PERL_VERSION
-  execute_process(
-COMMAND
-  ${PERL_EXECUTABLE} -V:version
-  OUTPUT_VARIABLE
-PERL_VERSION_OUTPUT_VARIABLE
-  RESULT_VARIABLE
-PERL_VERSION_RESULT_VARIABLE
-  )
-  if (NOT PERL_VERSION_RESULT_VARIABLE)
-string(REGEX REPLACE version='([^']+)'.* \\1 PERL_VERSION 
${PERL_VERSION_OUTPUT_VARIABLE})
-  endif (NOT PERL_VERSION_RESULT_VARIABLE)
-
   ### PERL_ARCHNAME
   execute_process(
 COMMAND
@@ -206,19 +193,19 @@ if (PERL_EXECUTABLE)
   ### PERL_POSSIBLE_INCLUDE_PATHS
   set(PERL_POSSIBLE_INCLUDE_PATHS
 ${PERL_ARCHLIB}/CORE
-/usr/lib/perl5/${PERL_VERSION}/${PERL_ARCHNAME}/CORE
-/usr/lib/perl/${PERL_VERSION}/${PERL_ARCHNAME}/CORE
-/usr/lib/perl5/${PERL_VERSION}/CORE
-/usr/lib/perl/${PERL_VERSION}/CORE
+/usr/lib/perl5/${PERL_VERSION_STRING}/${PERL_ARCHNAME}/CORE
+/usr/lib/perl/${PERL_VERSION_STRING}/${PERL_ARCHNAME}/CORE
+/usr/lib/perl5/${PERL_VERSION_STRING}/CORE
+/usr/lib/perl/${PERL_VERSION_STRING}/CORE
 )
 
   ### PERL_POSSIBLE_LIB_PATHS
   set(PERL_POSSIBLE_LIB_PATHS
 ${PERL_ARCHLIB}/CORE
-/usr/lib/perl5/${PERL_VERSION}/${PERL_ARCHNAME}/CORE
-/usr/lib/perl/${PERL_VERSION}/${PERL_ARCHNAME}/CORE
-/usr/lib/perl5/${PERL_VERSION}/CORE
-/usr/lib/perl/${PERL_VERSION}/CORE
+

[Cmake-commits] CMake branch, master, updated. v2.8.7-141-gf2baff9

2012-01-18 Thread KWSys Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  f2baff920e121377eb4873fc14783d64696270b1 (commit)
  from  b2838626ddb451fbbffe0de5990d309696b28dfc (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f2baff920e121377eb4873fc14783d64696270b1
commit f2baff920e121377eb4873fc14783d64696270b1
Author: KWSys Robot kwro...@kitware.com
AuthorDate: Thu Jan 19 00:05:08 2012 -0500
Commit: KWSys Robot kwro...@kitware.com
CommitDate: Thu Jan 19 00:05:08 2012 -0500

KWSys Nightly Date Stamp

diff --git a/Source/kwsys/kwsysDateStamp.cmake 
b/Source/kwsys/kwsysDateStamp.cmake
index 4625ed1..f8c725c 100644
--- a/Source/kwsys/kwsysDateStamp.cmake
+++ b/Source/kwsys/kwsysDateStamp.cmake
@@ -18,4 +18,4 @@ SET(KWSYS_DATE_STAMP_YEAR  2012)
 SET(KWSYS_DATE_STAMP_MONTH 01)
 
 # KWSys version date day component.  Format is DD.
-SET(KWSYS_DATE_STAMP_DAY   18)
+SET(KWSYS_DATE_STAMP_DAY   19)

---

Summary of changes:
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.7-2151-g9acf820

2012-01-18 Thread Rolf Eike Beer
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  9acf82052af98bee2624d6a2dd1cd42bd633a8a0 (commit)
   via  1b59013180f5a3581ffe05a34f8cfb42da6ab94d (commit)
   via  b2838626ddb451fbbffe0de5990d309696b28dfc (commit)
  from  2980cf8b255028a250c67d42351784af3cbf318d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9acf82052af98bee2624d6a2dd1cd42bd633a8a0
commit 9acf82052af98bee2624d6a2dd1cd42bd633a8a0
Merge: 2980cf8 1b59013
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 12:28:44 2012 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Wed Jan 18 12:28:44 2012 -0500

Merge topic 'perl-version' into next

1b59013 FindPerl{,Libs}: move version detection into FindPerl
b283862 KWSys Nightly Date Stamp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=1b59013180f5a3581ffe05a34f8cfb42da6ab94d
commit 1b59013180f5a3581ffe05a34f8cfb42da6ab94d
Author: Rolf Eike Beer e...@sf-mail.de
AuthorDate: Wed Jan 18 18:08:43 2012 +0100
Commit: Rolf Eike Beer e...@sf-mail.de
CommitDate: Wed Jan 18 18:28:19 2012 +0100

FindPerl{,Libs}: move version detection into FindPerl

diff --git a/Modules/FindPerl.cmake b/Modules/FindPerl.cmake
index db393e7..4ccb76c 100644
--- a/Modules/FindPerl.cmake
+++ b/Modules/FindPerl.cmake
@@ -1,8 +1,9 @@
 # - Find perl
 # this module looks for Perl
 #
 #  PERL_EXECUTABLE - the full path to perl
 #  PERL_FOUND  - If false, don't attempt to use perl.
 
 #=
 # Copyright 2001-2009 Kitware, Inc.
@@ -39,12 +40,31 @@ FIND_PROGRAM(PERL_EXECUTABLE
   PATHS ${PERL_POSSIBLE_BIN_PATHS}
   )
 
+IF(PERL_EXECUTABLE)
+  ### PERL_VERSION
+  EXECUTE_PROCESS(
+COMMAND
+  ${PERL_EXECUTABLE} -V:version
+  OUTPUT_VARIABLE
+PERL_VERSION_OUTPUT_VARIABLE
+  RESULT_VARIABLE
+PERL_VERSION_RESULT_VARIABLE
+  ERROR_QUIET
+  OUTPUT_STRIP_TRAILING_WHITESPACE
+  )
+  IF(NOT PERL_VERSION_RESULT_VARIABLE)
+STRING(REGEX REPLACE version='([^']+)'.* \\1 PERL_VERSION_STRING 
${PERL_VERSION_OUTPUT_VARIABLE})
+  ENDIF(NOT PERL_VERSION_RESULT_VARIABLE)
+ENDIF(PERL_EXECUTABLE)
+
 # Deprecated settings for compatibility with CMake1.4
 SET(PERL ${PERL_EXECUTABLE})
 
 # handle the QUIETLY and REQUIRED arguments and set PERL_FOUND to TRUE if 
 # all listed variables are TRUE
 INCLUDE(${CMAKE_CURRENT_LIST_DIR}/FindPackageHandleStandardArgs.cmake)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(Perl DEFAULT_MSG PERL_EXECUTABLE)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(Perl
+  REQUIRED_VARS PERL_EXECUTABLE
+  VERSION_VAR PERL_VERSION_STRING)
 
 MARK_AS_ADVANCED(PERL_EXECUTABLE)
@@ -1,8 +1,9 @@
 # this module looks for Perl
 #
-#  PERL_EXECUTABLE - the full path to perl
-#  PERL_FOUND  - If false, don't attempt to use perl.
+#  PERL_EXECUTABLE - the full path to perl
+#  PERL_FOUND  - If false, don't attempt to use perl.
+#  PERL_VERSION_STRING - version of perl found (since CMake 2.8.8)
 
 #=
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits